collectors.storage — Advanced storage backends — Collectors v0.2 documentation

### Navigation

- index
- modules |
- previous |
- Collectors v0.2 documentation »
- API-Reference »

# `collectors.storage` — Advanced storage backends

This module contains some advanced storage classes.

For your convenience, you can import the following classes directly from `collectors.storage`:

- `Excel`
- `PyTables`

## `collectors.storage.excel` — Store data in Excel sheets

## `collectors.storage.pytables` — Store data in HDF5 files

### Navigation

- index
- modules |
- previous |
- Collectors v0.2 documentation »
- API-Reference »